# Handling Events

To handle events, you'll need to create an event handler. An event handler is just a function that takes a single parameter of type `Event` and does something with it. An event handler could log events to the console, send them to a server through a WebSocket, or notify a Flutter app of a change in authentication state.

Plexus keeps track of these event handlers by storing their id and `StreamSubscription` in a map in the root module.

Plexus currently ships with a single event handler, `consoleHandler`, that formats, colors and logs events to stdout. `consoleHandler` has an optional parameter `io` of type `Stdout` that, if specified, is written to instead of the default `dart:io` stdout.

Handlers can be subscribed with the `subscribe` method found on instances of `Module`. The subscribe method takes a unique id which can be used later to unsubscribe the handler, and the event handler function.

```dart
someModule.subscribe('someId', consoleHandler);
```

If you want to pass extra parameters to an event handler, you can wrap it in a lambda.

```dart
subscribe('someId', (event) => consoleHandler(event, someStdout))
```
